@@ -48,16 +48,10 @@ function test_heat {
     openstack stack list
 }
 
-function install_requirements {
-    echo "TESTING: Install requirements"
-    pip install "python-tackerclient" "python-heatclient" "networking-sfc" "python-mistralclient" "python-barbicanclient"
-}
-
 function test_scenario_nfv_logged {
     . /etc/kolla/admin-openrc.sh
     . ~/openstackclient-venv/bin/activate
 
-    install_requirements
     test_tacker
     test_barbican
     test_mistral
